syncable library
Syncable is a library for offline-first multi-device data synchronization in Flutter apps.///
Classes
- Syncable
- An entity that can be synchronized between a local database and the backend.
- SyncableTable
- A Drift table that can be synchronized with a backend.
-
SyncManager<
T extends SyncableDatabase> - The SyncManager is the main class for syncing data between a local Drift database and a Supabase backend.
- SyncTimestampStorage
- Defines an interface for storing and retrieving sync timestamps.
Enums
Mixins
- SyncableDatabase
- A mixin to enable synchronization with a backend via a SyncManager.